import os
import io

os.environ['AZ_BUFFER_SIZE'] = str(io.DEFAULT_BUFFER_SIZE)
os.environ['TF_BUFFER_SIZE'] = str(io.DEFAULT_BUFFER_SIZE)

os.environ['AZ_CPP_MIN_LOG_LEVEL'] = '2'
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'

from .opsys import *
from .fsmod import *
from .rtenv import *
from .horology import *
from .calendar import *
from .random import *
from .gensysco import *
from .mtnetbri import *
from .tensorflow import *
from .keras import *
from .sklearn import *
from .dataprep import *
from .matplotlib import *
from .pyplot import *
from .numpy import *
from .pandas import *
from .tawizard import *
from .onnxkit import *

os.environ['AZ_CPP_MIN_LOG_LEVEL'] = '0'
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '0'



from numpy import *

def split_sequence(sequence, steps):
  x, y = list(), list()
  for i in range(len(sequence)):
    end = i + steps
    if end > len(sequence) - 1:
      break
    seq_x, seq_y = sequence[i:end], sequence[end]
    x.append(seq_x)
    y.append(seq_y)
  return array(x), array(y)
